import os
import click
from huggingface_hub import snapshot_download

def download_weights_from_hf(repo_id, save_path):
    """
    Downloads an entire folder from Hugging Face Model Hub.

    Args:
        repo_id (str): The Hugging Face repo ID.
        save_path (str): The local path to save the folder contents.
    """
    if not os.path.exists(save_path):
        os.makedirs(save_path, exist_ok=True)
        print("Downloading weights from Hugging Face...")
        snapshot_download(repo_id=repo_id, local_dir=save_path, repo_type="model")
        print(f"Weights downloaded to {save_path}")
    else:
        print("Weights already exist. Skipping download.")

@click.group()
def cli():
    """Command-line interface for OpenFace."""
    pass

@cli.command()
@click.option("--repo-id", default="nutPace/openface_weights", help="Hugging Face repo ID")
@click.option("--output", default="./weights", help="Path to save the weights")
def download(repo_id, output):
    """Download weights from Hugging Face."""
    save_path = os.path.abspath(output)
    download_weights_from_hf(repo_id, save_path)

# Attach the CLI group for OpenFace
if __name__ == "__main__":
    cli()
